@@ -2,6 +2,7 @@
 
 pub use super::tx;
 
+use crate::prelude::*;
 use crate::{Method, Order};
 use serde::{Deserialize, Serialize};
 
@@ -54,7 +55,3 @@ pub struct Response {
 }
 
 impl crate::Response for Response {}
-
-// TODO: remove this after the next breaking release
-#[deprecated(note = "use endpoint::tx::Response instead")]
-pub type ResultTx = tx::Response;
