@@ -1,10 +1,12 @@
 //! URL representation for RPC clients.
 
-use serde::de::Error;
+use crate::error::Error;
+use crate::prelude::*;
+use core::convert::TryFrom;
+use core::fmt;
+use core::str::FromStr;
+use serde::de::Error as SerdeError;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
-use std::convert::TryFrom;
-use std::fmt;
-use std::str::FromStr;
 
 /// The various schemes supported by Tendermint RPC clients.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
@@ -35,12 +37,7 @@ impl FromStr for Scheme {
             "https" => Scheme::Https,
             "ws" => Scheme::WebSocket,
             "wss" => Scheme::SecureWebSocket,
-            _ => {
-                return Err(crate::Error::invalid_params(&format!(
-                    "unsupported scheme: {}",
-                    s
-                )))
-            }
+            _ => return Err(Error::unsupported_scheme(s.to_string())),
         })
     }
 }
@@ -59,22 +56,20 @@ pub struct Url {
 }
 
 impl FromStr for Url {
-    type Err = crate::Error;
+    type Err = Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        let inner: url::Url = s.parse()?;
+        let inner: url::Url = s.parse().map_err(Error::parse_url)?;
+
         let scheme: Scheme = inner.scheme().parse()?;
+
         let host = inner
             .host_str()
-            .ok_or_else(|| {
-                crate::Error::invalid_params(&format!("URL is missing its host: {}", s))
-            })?
+            .ok_or_else(|| Error::invalid_params(format!("URL is missing its host: {}", s)))?
             .to_owned();
+
         let port = inner.port_or_known_default().ok_or_else(|| {
-            crate::Error::invalid_params(&format!(
-                "cannot determine appropriate port for URL: {}",
-                s
-            ))
+            Error::invalid_params(format!("cannot determine appropriate port for URL: {}", s))
         })?;
         Ok(Self {
             inner,
