@@ -1,11 +1,12 @@
 //! Tendermint kvstore RPC endpoint testing.
 
-use std::str::FromStr;
+use core::str::FromStr;
 use std::{fs, path::PathBuf};
 use subtle_encoding::{base64, hex};
 use tendermint::abci::transaction::Hash;
 use tendermint::evidence::Duration;
 use tendermint::public_key;
+use tendermint_config::net::Address;
 use tendermint_rpc::{
     endpoint,
     error::{Error, ErrorDetail},
@@ -96,6 +97,17 @@ fn outgoing_fixtures() {
                 .unwrap();
                 assert_eq!(wrapped.params().height.unwrap().value(), 10);
             }
+            "block_search" => {
+                let wrapped =
+                    serde_json::from_str::<RequestWrapper<endpoint::block_search::Request>>(
+                        &content,
+                    )
+                    .unwrap();
+                assert_eq!(wrapped.params().query, "block.height > 1");
+                assert_eq!(wrapped.params().page, 1);
+                assert_eq!(wrapped.params().per_page, 10);
+                assert_eq!(wrapped.params().order_by, Order::Ascending);
+            }
             "blockchain_from_1_to_10" => {
                 let wrapped =
                     serde_json::from_str::<RequestWrapper<endpoint::blockchain::Request>>(&content)
@@ -447,6 +459,48 @@ fn incoming_fixtures() {
                 assert!(result.txs_results.is_none());
                 assert!(result.validator_updates.is_empty());
             }
+            "block_search" => {
+                let result = endpoint::block_search::Response::from_string(content).unwrap();
+                assert_eq!(result.total_count as usize, result.blocks.len());
+                // Test a few selected attributes of the results.
+                for block in result.blocks {
+                    assert!(block.block.data.iter().next().is_none());
+                    assert!(block.block.evidence.iter().next().is_none());
+                    assert_eq!(block.block.header.app_hash.value(), [0u8; 8]);
+                    assert_eq!(block.block.header.chain_id.as_str(), CHAIN_ID);
+                    assert!(!block.block.header.consensus_hash.is_empty());
+                    assert!(block.block.header.data_hash.is_none());
+                    assert!(block.block.header.evidence_hash.is_none());
+                    assert_eq!(block.block.header.height.value(), 10);
+                    assert!(block.block.header.last_block_id.is_some());
+                    assert_eq!(block.block.header.last_commit_hash, empty_merkle_root_hash);
+                    assert_eq!(block.block.header.last_results_hash, empty_merkle_root_hash);
+                    assert!(!block.block.header.next_validators_hash.is_empty());
+                    assert_ne!(
+                        block.block.header.proposer_address.as_bytes(),
+                        [0u8; tendermint::account::LENGTH]
+                    );
+                    assert!(
+                        block
+                            .block
+                            .header
+                            .time
+                            .duration_since(informal_epoch)
+                            .unwrap()
+                            .as_secs()
+                            > 0
+                    );
+                    assert!(!block.block.header.validators_hash.is_empty());
+                    assert_eq!(
+                        block.block.header.version,
+                        tendermint::block::header::Version { block: 10, app: 1 }
+                    );
+                    assert!(block.block.last_commit.is_some());
+                    assert!(!block.block_id.hash.is_empty());
+                    assert!(!block.block_id.part_set_header.hash.is_empty());
+                    assert_eq!(block.block_id.part_set_header.total, 1);
+                }
+            }
             "blockchain_from_1_to_10" => {
                 let result = endpoint::blockchain::Response::from_string(content).unwrap();
                 assert_eq!(result.block_metas.len(), 10);
@@ -657,7 +711,7 @@ fn incoming_fixtures() {
                 assert_eq!(result.consensus_params.block.time_iota_ms, 500_i64);
                 assert_eq!(
                     result.consensus_params.evidence.max_age_duration,
-                    Duration(std::time::Duration::from_nanos(172800000000000_u64))
+                    Duration(core::time::Duration::from_nanos(172800000000000_u64))
                 );
                 assert_eq!(
                     result.consensus_params.evidence.max_age_num_blocks,
@@ -740,14 +794,14 @@ fn incoming_fixtures() {
             "status" => {
                 let result = endpoint::status::Response::from_string(content).unwrap();
                 assert_eq!(
-                    result.node_info.listen_addr.to_net_address().unwrap(),
-                    tendermint::net::Address::from_str("tcp://0.0.0.0:26656").unwrap()
+                    Address::from_listen_address(&result.node_info.listen_addr).unwrap(),
+                    Address::from_str("tcp://0.0.0.0:26656").unwrap()
                 );
                 assert_eq!(result.node_info.moniker.to_string(), "dockernode");
                 assert_eq!(result.node_info.network.to_string(), CHAIN_ID);
                 assert_eq!(
                     result.node_info.other.rpc_address,
-                    tendermint::net::Address::from_str("tcp://0.0.0.0:26657").unwrap()
+                    format!("{}", Address::from_str("tcp://0.0.0.0:26657").unwrap())
                 );
                 assert_eq!(
                     result.node_info.other.tx_index,
